@@ -1,7 +1,7 @@
 /*
   math.c
   Ruby/GSL: Ruby extension library for GSL (GNU Scientific Library)
-    (C) Copyright 2001-2004 by Yoshiki Tsunesada
+    (C) Copyright 2001-2006 by Yoshiki Tsunesada
 
   Ruby/GSL is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License.
@@ -318,7 +318,6 @@ static VALUE rb_gsl_pow(VALUE obj, VALUE xx, VALUE nn)
   double n;
   gsl_vector *v = NULL, *vnew = NULL;
   gsl_matrix *m = NULL, *mnew = NULL;
-  gsl_vector *vn = NULL;
 #ifdef HAVE_NARRAY_H
   struct NARRAY *na;
   double *ptr1, *ptr2;
@@ -703,7 +702,7 @@ void Init_gsl_math(VALUE module)
   rb_define_module_function(module, "MIN_INT", rb_GSL_MIN_INT, 2);
 
   rb_define_module_function(module, "fcmp", rb_gsl_fcmp, -1);
-  rb_define_module_function(module, "equal?", rb_gsl_equal, -1);
+  rb_define_singleton_method(module, "equal?", rb_gsl_equal, -1);
 #ifdef GSL_1_3_LATER
   rb_define_module_function(module, "ldexp", rb_gsl_ldexp, 2);
   rb_define_module_function(module, "frexp", rb_gsl_frexp, 1);
