@@ -586,7 +586,6 @@ static VALUE rb_gsl_multifit_function_fdf_set_data(int argc, VALUE *argv, VALUE
 {
   VALUE ary, ary2;
   gsl_multifit_function_fdf *func = NULL;
-  gsl_vector *v = NULL;
   Data_Get_Struct(obj, gsl_multifit_function_fdf, func);
   if (func->params == NULL) {
     ary = rb_ary_new2(4);
@@ -624,13 +623,13 @@ static int gsl_multifit_function_fdf_f(const gsl_vector *x, void *params,
   case 2:
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
-    rb_funcall(proc, ID_call, 4, vx, vt, vy, vf);
+    rb_funcall(proc, RBGSL_ID_call, 4, vx, vt, vy, vf);
     break;
   case 3:
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
     vsigma = rb_ary_entry(vt_y_sigma,2);
-    rb_funcall(proc, ID_call, 5, vx, vt, vy, vsigma, vf);
+    rb_funcall(proc, RBGSL_ID_call, 5, vx, vt, vy, vsigma, vf);
     break;
   default:
     rb_raise(rb_eArgError, "bad argument");
@@ -652,13 +651,13 @@ static int gsl_multifit_function_fdf_df(const gsl_vector *x, void *params,
   case 2:
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
-    rb_funcall(proc, ID_call, 4, vx, vt, vy, vJ);
+    rb_funcall(proc, RBGSL_ID_call, 4, vx, vt, vy, vJ);
     break;
   case 3:
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
     vsigma = rb_ary_entry(vt_y_sigma,2);
-    rb_funcall(proc, ID_call, 5, vx, vt, vy, vsigma, vJ);
+    rb_funcall(proc, RBGSL_ID_call, 5, vx, vt, vy, vsigma, vJ);
     break;
   default:
     rb_raise(rb_eArgError, "bad argument");
@@ -685,20 +684,20 @@ static int gsl_multifit_function_fdf_fdf(const gsl_vector *x, void *params,
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
     if (NIL_P(proc_fdf)) {
-      rb_funcall(proc_f, ID_call, 4, vx, vt, vy, vf);
-      rb_funcall(proc_df, ID_call, 4, vx, vt, vy, vJ);
+      rb_funcall(proc_f, RBGSL_ID_call, 4, vx, vt, vy, vf);
+      rb_funcall(proc_df, RBGSL_ID_call, 4, vx, vt, vy, vJ);
     } else 
-      rb_funcall(proc_fdf, ID_call, 5, vx, vt, vy, vf, vJ);
+      rb_funcall(proc_fdf, RBGSL_ID_call, 5, vx, vt, vy, vf, vJ);
     break;
   case 3:
     vt = rb_ary_entry(vt_y_sigma, 0);
     vy = rb_ary_entry(vt_y_sigma, 1);
     vsigma = rb_ary_entry(vt_y_sigma,2);
     if (NIL_P(proc_fdf)) {
-      rb_funcall(proc_f, ID_call, 5, vx, vt, vy, vsigma, vf);
-      rb_funcall(proc_df, ID_call, 5, vx, vt, vy, vsigma, vJ);
+      rb_funcall(proc_f, RBGSL_ID_call, 5, vx, vt, vy, vsigma, vf);
+      rb_funcall(proc_df, RBGSL_ID_call, 5, vx, vt, vy, vsigma, vJ);
     } else 
-      rb_funcall(proc_fdf, ID_call, 6, vx, vt, vy, vsigma, vf, vJ);
+      rb_funcall(proc_fdf, RBGSL_ID_call, 6, vx, vt, vy, vsigma, vf, vJ);
     break;
   default:
     rb_raise(rb_eArgError, "bad argument");
