@@ -1,7 +1,7 @@
 /*
   vector.c
   Ruby/GSL: Ruby extension library for GSL (GNU Scientific Library)
-    (C) Copyright 2001-2004 by Yoshiki Tsunesada
+    (C) Copyright 2001-2006 by Yoshiki Tsunesada
         Modified by Seiya Nishizawa        14/Apr/2004
 
   Ruby/GSL is free software: you can redistribute it and/or modify it
@@ -1161,6 +1161,84 @@ static VALUE rb_gsl_vector_rotate(int argc, VALUE *argv, VALUE klass)
 		     Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vynew));
 }
 
+#include "gsl/gsl_fit.h"
+
+static VALUE rb_gsl_vector_linearfit(int argc, VALUE *argv, VALUE klass)
+{
+  gsl_vector *x, *y, *w = NULL;
+  double c0, c1, c00, c01, c11, sumsq;
+  switch (argc) {
+  case 3:
+    CHECK_VECTOR(argv[0]); CHECK_VECTOR(argv[1]); CHECK_VECTOR(argv[2]);
+    Data_Get_Struct(argv[0], gsl_vector, x);
+    Data_Get_Struct(argv[1], gsl_vector, w);
+    Data_Get_Struct(argv[2], gsl_vector, y);
+    gsl_fit_wlinear(x->data, x->stride, w->data, w->stride,
+		    y->data, y->stride, y->size, &c0, &c1, &c00, &c01, &c11,
+		    &sumsq);
+    break;
+  case 2:
+    CHECK_VECTOR(argv[0]); CHECK_VECTOR(argv[1]); 
+    Data_Get_Struct(argv[0], gsl_vector, x);
+    Data_Get_Struct(argv[1], gsl_vector, y);
+    gsl_fit_linear(x->data, x->stride, y->data,y->stride, y->size, 
+		   &c0, &c1, &c00, &c01, &c11, &sumsq);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 2 or 3).\n", argc);
+  }
+  return rb_ary_new3(6, rb_float_new(c0), rb_float_new(c1), rb_float_new(c00),
+		    rb_float_new(c01), rb_float_new(c11), rb_float_new(sumsq));
+}
+
+static VALUE rb_gsl_vector_center(VALUE obj)
+{
+  gsl_vector *v, *vnew;
+  double mean;
+  Data_Get_Struct(obj, gsl_vector, v);
+  mean = gsl_stats_mean(v->data, v->stride, v->size);
+  vnew = gsl_vector_alloc(v->size);
+  gsl_vector_memcpy(vnew, v);
+  gsl_vector_add_constant(vnew, -mean);
+  return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vnew);
+}
+
+static VALUE rb_gsl_vector_clip(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_vector *v, *vnew;  
+  double hi = 1.0, lo = 0.0;
+  double x;
+  size_t i;
+  Data_Get_Struct(obj, gsl_vector, v);
+  switch (argc) {
+  case 0:
+    break;
+  case 1:
+    if (TYPE(argv[0]) == T_ARRAY) {
+      lo = NUM2DBL(rb_ary_entry(argv[0], 0));
+      hi = NUM2DBL(rb_ary_entry(argv[0], 1));
+    } else {
+      hi = NUM2DBL(argv[0]);
+    }
+    break;
+  case 2:
+    lo = NUM2DBL(argv[0]);
+    hi = NUM2DBL(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 0-2).\n", argc);
+  }
+  vnew = gsl_vector_alloc(v->size);
+  for (i = 0; i < v->size; i++) {
+    x = gsl_vector_get(v, i);
+    if (x > hi) x = hi;
+    else if (x < lo) x = lo;
+    else;
+    gsl_vector_set(vnew, i, x);
+  }
+  return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vnew);
+}
+
 void Init_gsl_vector(VALUE module)
 {
   rb_define_singleton_method(cgsl_vector, "linspace", rb_gsl_vector_linspace, -1);
@@ -1235,5 +1313,10 @@ void Init_gsl_vector(VALUE module)
   rb_define_singleton_method(cgsl_vector, "rotate", rb_gsl_vector_rotate, -1);
   rb_define_singleton_method(cgsl_vector, "rotate!", rb_gsl_vector_rotate_bang, -1);
 
+  rb_define_singleton_method(cgsl_vector, "linearfit", rb_gsl_vector_linearfit, -1);
+
+  rb_define_method(cgsl_vector, "center", rb_gsl_vector_center, 0);
+  rb_define_method(cgsl_vector, "clip", rb_gsl_vector_clip, -1);
+
   Init_gsl_vector_init(module);
 }
