@@ -2,7 +2,7 @@
 #define ___RB_GSL_CONFIG_H___
 
 #ifndef GSL_VERSION
-#define GSL_VERSION "1.8"
+#define GSL_VERSION "1.9"
 #endif
 #ifndef GSL_0_9_4_LATER
 #define GSL_0_9_4_LATER
@@ -34,8 +34,14 @@
 #ifndef GSL_1_8_LATER
 #define GSL_1_8_LATER
 #endif
+#ifndef GSL_1_9_LATER
+#define GSL_1_9_LATER
+#endif
+#ifndef HAVE_EIGEN_FRANCIS
+#define HAVE_EIGEN_FRANCIS
+#endif
 #ifndef RUBY_GSL_VERSION
-#define RUBY_GSL_VERSION "1.8.0"
+#define RUBY_GSL_VERSION "1.9.0"
 #endif
 #ifndef RUBY_1_8_LATER
 #define RUBY_1_8_LATER
